# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/bootstrap/v3/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/bootstrap/v3/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from envoy.config.core.v3 import socket_option_pb2 as envoy_dot_config_dot_core_dot_v3_dot_socket__option__pb2
from envoy.config.listener.v3 import listener_pb2 as envoy_dot_config_dot_listener_dot_v3_dot_listener__pb2
from envoy.config.metrics.v3 import stats_pb2 as envoy_dot_config_dot_metrics_dot_v3_dot_stats__pb2
from envoy.config.overload.v3 import overload_pb2 as envoy_dot_config_dot_overload_dot_v3_dot_overload__pb2
from envoy.config.trace.v3 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/bootstrap/v3/bootstrap.proto\x12\x19\x65nvoy.config.bootstrap.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a%envoy/config/cluster/v3/cluster.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a/envoy/config/core/v3/event_service_config.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a(envoy/config/core/v3/socket_option.proto\x1a\'envoy/config/listener/v3/listener.proto\x1a#envoy/config/metrics/v3/stats.proto\x1a\'envoy/config/overload/v3/overload.proto\x1a\'envoy/config/trace/v3/http_tracer.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x1d\n\tBootstrap\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x1b\n\x13node_context_params\x18\x1a \x03(\t\x12N\n\x10static_resources\x18\x02 \x01(\x0b\x32\x34.envoy.config.bootstrap.v3.Bootstrap.StaticResources\x12P\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32\x35.envoy.config.bootstrap.v3.Bootstrap.DynamicResources\x12\x42\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32).envoy.config.bootstrap.v3.ClusterManager\x12\x39\n\nhds_config\x18\x0e \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12\x37\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\".envoy.config.metrics.v3.StatsSink\x12W\n\x15\x64\x65\x66\x65rred_stat_options\x18\' \x01(\x0b\x32\x38.envoy.config.bootstrap.v3.Bootstrap.DeferredStatOptions\x12:\n\x0cstats_config\x18\r \x01(\x0b\x32$.envoy.config.metrics.v3.StatsConfig\x12]\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=\xf2\x98\xfe\x8f\x05\r\x12\x0bstats_flush\x12\'\n\x14stats_flush_on_admin\x18\x1d \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x42\n\x08watchdog\x18\x08 \x01(\x0b\x32#.envoy.config.bootstrap.v3.WatchdogB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x37\n\twatchdogs\x18\x1b \x01(\x0b\x32$.envoy.config.bootstrap.v3.Watchdogs\x12<\n\x07tracing\x18\t \x01(\x0b\x32\x1e.envoy.config.trace.v3.TracingB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x42\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32).envoy.config.bootstrap.v3.LayeredRuntime\x12/\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32 .envoy.config.bootstrap.v3.Admin\x12N\n\x10overload_manager\x18\x0f \x01(\x0b\x32).envoy.config.overload.v3.OverloadManagerB\t\x8a\x93\xb7*\x04\x08\x01\x10\x01\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\x1e \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x1f \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12H\n\x14\x62ootstrap_extensions\x18\x15 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12=\n\rfatal_actions\x18\x1c \x03(\x0b\x32&.envoy.config.bootstrap.v3.FatalAction\x12:\n\x0e\x63onfig_sources\x18\x16 \x03(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x41\n\x15\x64\x65\x66\x61ult_config_source\x18\x17 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12 \n\x18\x64\x65\x66\x61ult_socket_interface\x18\x18 \x01(\t\x12n\n\x1e\x63\x65rtificate_provider_instances\x18\x19 \x03(\x0b\x32\x46.envoy.config.bootstrap.v3.Bootstrap.CertificateProviderInstancesEntry\x12\x45\n\x0einline_headers\x18  \x03(\x0b\x32-.envoy.config.bootstrap.v3.CustomInlineHeader\x12\x1e\n\x16perf_tracing_file_path\x18! \x01(\t\x12H\n\x14\x64\x65\x66\x61ult_regex_engine\x18\" \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12J\n\x16xds_delegate_extension\x18# \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12P\n\x1cxds_config_tracker_extension\x18$ \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x44\n\x10listener_manager\x18% \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12Y\n\x16\x61pplication_log_config\x18& \x01(\x0b\x32\x39.envoy.config.bootstrap.v3.Bootstrap.ApplicationLogConfig\x12k\n grpc_async_client_manager_config\x18( \x01(\x0b\x32\x41.envoy.config.bootstrap.v3.Bootstrap.GrpcAsyncClientManagerConfig\x12S\n\x18memory_allocator_manager\x18) \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.MemoryAllocatorManager\x1a\xfc\x01\n\x0fStaticResources\x12\x35\n\tlisteners\x18\x01 \x03(\x0b\x32\".envoy.config.listener.v3.Listener\x12\x32\n\x08\x63lusters\x18\x02 \x03(\x0b\x32 .envoy.config.cluster.v3.Cluster\x12\x42\n\x07secrets\x18\x03 \x03(\x0b\x32\x31.envoy.extensions.transport_sockets.tls.v3.Secret::\x9a\xc5\x88\x1e\x35\n3envoy.config.bootstrap.v2.Bootstrap.StaticResources\x1a\xbe\x02\n\x10\x44ynamicResources\x12\x36\n\nlds_config\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x1d\n\x15lds_resources_locator\x18\x05 \x01(\t\x12\x36\n\ncds_config\x18\x02 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource\x12\x1d\n\x15\x63\x64s_resources_locator\x18\x06 \x01(\t\x12\x39\n\nads_config\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource:;\x9a\xc5\x88\x1e\x36\n4envoy.config.bootstrap.v2.Bootstrap.DynamicResourcesJ\x04\x08\x04\x10\x05\x1a\xd6\x01\n\x14\x41pplicationLogConfig\x12W\n\nlog_format\x18\x01 \x01(\x0b\x32\x43.envoy.config.bootstrap.v3.Bootstrap.ApplicationLogConfig.LogFormat\x1a\x65\n\tLogFormat\x12.\n\x0bjson_format\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x15\n\x0btext_format\x18\x02 \x01(\tH\x00\x42\x11\n\nlog_format\x12\x03\xf8\x42\x01\x1a=\n\x13\x44\x65\x66\x65rredStatOptions\x12&\n\x1e\x65nable_deferred_creation_stats\x18\x01 \x01(\x08\x1am\n\x1cGrpcAsyncClientManagerConfig\x12M\n\x1emax_cached_entry_idle_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x05\x1ao\n!CertificateProviderInstancesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig:\x02\x38\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.bootstrap.v2.BootstrapB\r\n\x0bstats_flushJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cR\x07runtime\"\xb3\x02\n\x05\x41\x64min\x12\x38\n\naccess_log\x18\x05 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12$\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12.\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12:\n\x0esocket_options\x18\x04 \x03(\x0b\x32\".envoy.config.core.v3.SocketOption\x12 \n\x18ignore_global_conn_limit\x18\x06 \x01(\x08:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.bootstrap.v2.Admin\"\x90\x04\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12U\n\x11outlier_detection\x18\x02 \x01(\x0b\x32:.envoy.config.bootstrap.v3.ClusterManager.OutlierDetection\x12>\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.BindConfig\x12@\n\x11load_stats_config\x18\x04 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSource\x12(\n enable_deferred_cluster_creation\x18\x05 \x01(\x08\x1a\xad\x01\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12?\n\revent_service\x18\x02 \x01(\x0b\x32(.envoy.config.core.v3.EventServiceConfig:@\x9a\xc5\x88\x1e;\n9envoy.config.bootstrap.v2.ClusterManager.OutlierDetection:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v2.ClusterManager\"\x8c\x01\n\tWatchdogs\x12\x41\n\x14main_thread_watchdog\x18\x01 \x01(\x0b\x32#.envoy.config.bootstrap.v3.Watchdog\x12<\n\x0fworker_watchdog\x18\x02 \x01(\x0b\x32#.envoy.config.bootstrap.v3.Watchdog\"\xbb\x05\n\x08Watchdog\x12\x43\n\x07\x61\x63tions\x18\x07 \x03(\x0b\x32\x32.envoy.config.bootstrap.v3.Watchdog.WatchdogAction\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x44\n\x17max_kill_timeout_jitter\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x32\x00\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x13multikill_threshold\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x1a\xf6\x01\n\x0eWatchdogAction\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12Y\n\x05\x65vent\x18\x02 \x01(\x0e\x32@.envoy.config.bootstrap.v3.Watchdog.WatchdogAction.WatchdogEventB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"M\n\rWatchdogEvent\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04KILL\x10\x01\x12\r\n\tMULTIKILL\x10\x02\x12\x0c\n\x08MEGAMISS\x10\x03\x12\x08\n\x04MISS\x10\x04:)\x9a\xc5\x88\x1e$\n\"envoy.config.bootstrap.v2.Watchdog\"I\n\x0b\x46\x61talAction\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\"\xa5\x01\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct:(\x9a\xc5\x88\x1e#\n!envoy.config.bootstrap.v2.Runtime\"\xe3\x05\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12G\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.RuntimeLayer.DiskLayerH\x00\x12I\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x32.envoy.config.bootstrap.v3.RuntimeLayer.AdminLayerH\x00\x12G\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x31.envoy.config.bootstrap.v3.RuntimeLayer.RtdsLayerH\x00\x1a\x90\x01\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer\x1a\x46\n\nAdminLayer:8\x9a\xc5\x88\x1e\x33\n1envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer\x1a\x8b\x01\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x0brtds_config\x18\x02 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource:7\x9a\xc5\x88\x1e\x32\n0envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer:-\x9a\xc5\x88\x1e(\n&envoy.config.bootstrap.v2.RuntimeLayerB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"z\n\x0eLayeredRuntime\x12\x37\n\x06layers\x18\x01 \x03(\x0b\x32\'.envoy.config.bootstrap.v3.RuntimeLayer:/\x9a\xc5\x88\x1e*\n(envoy.config.bootstrap.v2.LayeredRuntime\"\x8d\x02\n\x12\x43ustomInlineHeader\x12)\n\x12inline_header_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x64\n\x12inline_header_type\x18\x02 \x01(\x0e\x32>.envoy.config.bootstrap.v3.CustomInlineHeader.InlineHeaderTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"f\n\x10InlineHeaderType\x12\x12\n\x0eREQUEST_HEADER\x10\x00\x12\x13\n\x0fREQUEST_TRAILER\x10\x01\x12\x13\n\x0fRESPONSE_HEADER\x10\x02\x12\x14\n\x10RESPONSE_TRAILER\x10\x03\"n\n\x16MemoryAllocatorManager\x12\x18\n\x10\x62ytes_to_release\x18\x01 \x01(\x04\x12:\n\x17memory_release_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x91\x01\n\'io.envoyproxy.envoy.config.bootstrap.v3B\x0e\x42ootstrapProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v3;bootstrapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.bootstrap.v3.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.bootstrap.v3B\016BootstrapProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v3;bootstrapv3\272\200\310\321\006\002\020\002'
  _globals['_BOOTSTRAP_STATICRESOURCES']._loaded_options = None
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_options = b'\232\305\210\0365\n3envoy.config.bootstrap.v2.Bootstrap.StaticResources'
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._loaded_options = None
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_options = b'\232\305\210\0366\n4envoy.config.bootstrap.v2.Bootstrap.DynamicResources'
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT'].oneofs_by_name['log_format']._loaded_options = None
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT'].oneofs_by_name['log_format']._serialized_options = b'\370B\001'
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG'].fields_by_name['max_cached_entry_idle_duration']._loaded_options = None
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG'].fields_by_name['max_cached_entry_idle_duration']._serialized_options = b'\372B\007\252\001\0042\002\010\005'
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._loaded_options = None
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_options = b'8\001'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._serialized_options = b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204=\362\230\376\217\005\r\022\013stats_flush'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_on_admin']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_on_admin']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_BOOTSTRAP'].fields_by_name['watchdog']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['watchdog']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['tracing']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['tracing']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['overload_manager']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['overload_manager']._serialized_options = b'\212\223\267*\004\010\001\020\001'
  _globals['_BOOTSTRAP'].fields_by_name['use_tcp_for_dns_lookups']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['use_tcp_for_dns_lookups']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP'].fields_by_name['dns_resolution_config']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BOOTSTRAP']._loaded_options = None
  _globals['_BOOTSTRAP']._serialized_options = b'\232\305\210\036%\n#envoy.config.bootstrap.v2.Bootstrap'
  _globals['_ADMIN'].fields_by_name['access_log_path']._loaded_options = None
  _globals['_ADMIN'].fields_by_name['access_log_path']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\232\305\210\036!\n\037envoy.config.bootstrap.v2.Admin'
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._loaded_options = None
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_options = b'\232\305\210\036;\n9envoy.config.bootstrap.v2.ClusterManager.OutlierDetection'
  _globals['_CLUSTERMANAGER']._loaded_options = None
  _globals['_CLUSTERMANAGER']._serialized_options = b'\232\305\210\036*\n(envoy.config.bootstrap.v2.ClusterManager'
  _globals['_WATCHDOG_WATCHDOGACTION'].fields_by_name['event']._loaded_options = None
  _globals['_WATCHDOG_WATCHDOGACTION'].fields_by_name['event']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_WATCHDOG'].fields_by_name['max_kill_timeout_jitter']._loaded_options = None
  _globals['_WATCHDOG'].fields_by_name['max_kill_timeout_jitter']._serialized_options = b'\372B\005\252\001\0022\000'
  _globals['_WATCHDOG']._loaded_options = None
  _globals['_WATCHDOG']._serialized_options = b'\232\305\210\036$\n\"envoy.config.bootstrap.v2.Watchdog'
  _globals['_RUNTIME']._loaded_options = None
  _globals['_RUNTIME']._serialized_options = b'\232\305\210\036#\n!envoy.config.bootstrap.v2.Runtime'
  _globals['_RUNTIMELAYER_DISKLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_options = b'\232\305\210\0362\n0envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer'
  _globals['_RUNTIMELAYER_ADMINLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_options = b'\232\305\210\0363\n1envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer'
  _globals['_RUNTIMELAYER_RTDSLAYER']._loaded_options = None
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_options = b'\232\305\210\0362\n0envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer'
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._loaded_options = None
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._serialized_options = b'\370B\001'
  _globals['_RUNTIMELAYER'].fields_by_name['name']._loaded_options = None
  _globals['_RUNTIMELAYER'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RUNTIMELAYER']._loaded_options = None
  _globals['_RUNTIMELAYER']._serialized_options = b'\232\305\210\036(\n&envoy.config.bootstrap.v2.RuntimeLayer'
  _globals['_LAYEREDRUNTIME']._loaded_options = None
  _globals['_LAYEREDRUNTIME']._serialized_options = b'\232\305\210\036*\n(envoy.config.bootstrap.v2.LayeredRuntime'
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_name']._loaded_options = None
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_type']._loaded_options = None
  _globals['_CUSTOMINLINEHEADER'].fields_by_name['inline_header_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_BOOTSTRAP']._serialized_start=964
  _globals['_BOOTSTRAP']._serialized_end=4678
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_start=3521
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_end=3773
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_start=3776
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_end=4094
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG']._serialized_start=4097
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG']._serialized_end=4311
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT']._serialized_start=4210
  _globals['_BOOTSTRAP_APPLICATIONLOGCONFIG_LOGFORMAT']._serialized_end=4311
  _globals['_BOOTSTRAP_DEFERREDSTATOPTIONS']._serialized_start=4313
  _globals['_BOOTSTRAP_DEFERREDSTATOPTIONS']._serialized_end=4374
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG']._serialized_start=4376
  _globals['_BOOTSTRAP_GRPCASYNCCLIENTMANAGERCONFIG']._serialized_end=4485
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_start=4487
  _globals['_BOOTSTRAP_CERTIFICATEPROVIDERINSTANCESENTRY']._serialized_end=4598
  _globals['_ADMIN']._serialized_start=4681
  _globals['_ADMIN']._serialized_end=4988
  _globals['_CLUSTERMANAGER']._serialized_start=4991
  _globals['_CLUSTERMANAGER']._serialized_end=5519
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_start=5297
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_end=5470
  _globals['_WATCHDOGS']._serialized_start=5522
  _globals['_WATCHDOGS']._serialized_end=5662
  _globals['_WATCHDOG']._serialized_start=5665
  _globals['_WATCHDOG']._serialized_end=6364
  _globals['_WATCHDOG_WATCHDOGACTION']._serialized_start=6075
  _globals['_WATCHDOG_WATCHDOGACTION']._serialized_end=6321
  _globals['_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT']._serialized_start=6244
  _globals['_WATCHDOG_WATCHDOGACTION_WATCHDOGEVENT']._serialized_end=6321
  _globals['_FATALACTION']._serialized_start=6366
  _globals['_FATALACTION']._serialized_end=6439
  _globals['_RUNTIME']._serialized_start=6442
  _globals['_RUNTIME']._serialized_end=6607
  _globals['_RUNTIMELAYER']._serialized_start=6610
  _globals['_RUNTIMELAYER']._serialized_end=7349
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_start=6920
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_end=7064
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_start=7066
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_end=7136
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_start=7139
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_end=7278
  _globals['_LAYEREDRUNTIME']._serialized_start=7351
  _globals['_LAYEREDRUNTIME']._serialized_end=7473
  _globals['_CUSTOMINLINEHEADER']._serialized_start=7476
  _globals['_CUSTOMINLINEHEADER']._serialized_end=7745
  _globals['_CUSTOMINLINEHEADER_INLINEHEADERTYPE']._serialized_start=7643
  _globals['_CUSTOMINLINEHEADER_INLINEHEADERTYPE']._serialized_end=7745
  _globals['_MEMORYALLOCATORMANAGER']._serialized_start=7747
  _globals['_MEMORYALLOCATORMANAGER']._serialized_end=7857
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: opentelemetry/proto/metrics/v1/metrics.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'opentelemetry/proto/metrics/v1/metrics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from opentelemetry.proto.resource.v1 import resource_pb2 as opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,opentelemetry/proto/metrics/v1/metrics.proto\x12\x1eopentelemetry.proto.metrics.v1\x1a*opentelemetry/proto/common/v1/common.proto\x1a.opentelemetry/proto/resource/v1/resource.proto\"\xca\x01\n\x0fResourceMetrics\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).opentelemetry.proto.resource.v1.Resource\x12\x66\n\x1finstrumentation_library_metrics\x18\x02 \x03(\x0b\x32=.opentelemetry.proto.metrics.v1.InstrumentationLibraryMetrics\x12\x12\n\nschema_url\x18\x03 \x01(\t\"\xc4\x01\n\x1dInstrumentationLibraryMetrics\x12V\n\x17instrumentation_library\x18\x01 \x01(\x0b\x32\x35.opentelemetry.proto.common.v1.InstrumentationLibrary\x12\x37\n\x07metrics\x18\x02 \x03(\x0b\x32&.opentelemetry.proto.metrics.v1.Metric\x12\x12\n\nschema_url\x18\x03 \x01(\t\"\xf6\x03\n\x06Metric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12\x41\n\tint_gauge\x18\x04 \x01(\x0b\x32(.opentelemetry.proto.metrics.v1.IntGaugeB\x02\x18\x01H\x00\x12\x36\n\x05gauge\x18\x05 \x01(\x0b\x32%.opentelemetry.proto.metrics.v1.GaugeH\x00\x12=\n\x07int_sum\x18\x06 \x01(\x0b\x32&.opentelemetry.proto.metrics.v1.IntSumB\x02\x18\x01H\x00\x12\x32\n\x03sum\x18\x07 \x01(\x0b\x32#.opentelemetry.proto.metrics.v1.SumH\x00\x12I\n\rint_histogram\x18\x08 \x01(\x0b\x32,.opentelemetry.proto.metrics.v1.IntHistogramB\x02\x18\x01H\x00\x12>\n\thistogram\x18\t \x01(\x0b\x32).opentelemetry.proto.metrics.v1.HistogramH\x00\x12:\n\x07summary\x18\x0b \x01(\x0b\x32\'.opentelemetry.proto.metrics.v1.SummaryH\x00\x42\x06\n\x04\x64\x61ta\"M\n\x05Gauge\x12\x44\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32/.opentelemetry.proto.metrics.v1.NumberDataPoint\"\xba\x01\n\x03Sum\x12\x44\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32/.opentelemetry.proto.metrics.v1.NumberDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\x12\x14\n\x0cis_monotonic\x18\x03 \x01(\x08\"\xad\x01\n\tHistogram\x12G\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x32.opentelemetry.proto.metrics.v1.HistogramDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\"P\n\x07Summary\x12\x45\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x30.opentelemetry.proto.metrics.v1.SummaryDataPoint\"\xb4\x02\n\x0fNumberDataPoint\x12;\n\nattributes\x18\x07 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12\x41\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValueB\x02\x18\x01\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\x13\n\tas_double\x18\x04 \x01(\x01H\x00\x12\x10\n\x06\x61s_int\x18\x06 \x01(\x10H\x00\x12;\n\texemplars\x18\x05 \x03(\x0b\x32(.opentelemetry.proto.metrics.v1.ExemplarB\x07\n\x05value\"\xd3\x02\n\x12HistogramDataPoint\x12;\n\nattributes\x18\t \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12\x41\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValueB\x02\x18\x01\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05\x63ount\x18\x04 \x01(\x06\x12\x0b\n\x03sum\x18\x05 \x01(\x01\x12\x15\n\rbucket_counts\x18\x06 \x03(\x06\x12\x17\n\x0f\x65xplicit_bounds\x18\x07 \x03(\x01\x12;\n\texemplars\x18\x08 \x03(\x0b\x32(.opentelemetry.proto.metrics.v1.Exemplar\"\xf3\x02\n\x10SummaryDataPoint\x12;\n\nattributes\x18\x07 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12\x41\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValueB\x02\x18\x01\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05\x63ount\x18\x04 \x01(\x06\x12\x0b\n\x03sum\x18\x05 \x01(\x01\x12Y\n\x0fquantile_values\x18\x06 \x03(\x0b\x32@.opentelemetry.proto.metrics.v1.SummaryDataPoint.ValueAtQuantile\x1a\x32\n\x0fValueAtQuantile\x12\x10\n\x08quantile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01\"\x87\x02\n\x08\x45xemplar\x12\x44\n\x13\x66iltered_attributes\x18\x07 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12J\n\x0f\x66iltered_labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValueB\x02\x18\x01\x12\x16\n\x0etime_unix_nano\x18\x02 \x01(\x06\x12\x13\n\tas_double\x18\x03 \x01(\x01H\x00\x12\x10\n\x06\x61s_int\x18\x06 \x01(\x10H\x00\x12\x0f\n\x07span_id\x18\x04 \x01(\x0c\x12\x10\n\x08trace_id\x18\x05 \x01(\x0c\x42\x07\n\x05value\"\xd6\x01\n\x0cIntDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05value\x18\x04 \x01(\x10\x12>\n\texemplars\x18\x05 \x03(\x0b\x32+.opentelemetry.proto.metrics.v1.IntExemplar:\x02\x18\x01\"Q\n\x08IntGauge\x12\x41\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32,.opentelemetry.proto.metrics.v1.IntDataPoint:\x02\x18\x01\"\xbe\x01\n\x06IntSum\x12\x41\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32,.opentelemetry.proto.metrics.v1.IntDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality\x12\x14\n\x0cis_monotonic\x18\x03 \x01(\x08:\x02\x18\x01\"\x9c\x02\n\x15IntHistogramDataPoint\x12=\n\x06labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x16\n\x0etime_unix_nano\x18\x03 \x01(\x06\x12\r\n\x05\x63ount\x18\x04 \x01(\x06\x12\x0b\n\x03sum\x18\x05 \x01(\x10\x12\x15\n\rbucket_counts\x18\x06 \x03(\x06\x12\x17\n\x0f\x65xplicit_bounds\x18\x07 \x03(\x01\x12>\n\texemplars\x18\x08 \x03(\x0b\x32+.opentelemetry.proto.metrics.v1.IntExemplar:\x02\x18\x01\"\xb7\x01\n\x0cIntHistogram\x12J\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x35.opentelemetry.proto.metrics.v1.IntHistogramDataPoint\x12W\n\x17\x61ggregation_temporality\x18\x02 \x01(\x0e\x32\x36.opentelemetry.proto.metrics.v1.AggregationTemporality:\x02\x18\x01\"\xa3\x01\n\x0bIntExemplar\x12\x46\n\x0f\x66iltered_labels\x18\x01 \x03(\x0b\x32-.opentelemetry.proto.common.v1.StringKeyValue\x12\x16\n\x0etime_unix_nano\x18\x02 \x01(\x06\x12\r\n\x05value\x18\x03 \x01(\x10\x12\x0f\n\x07span_id\x18\x04 \x01(\x0c\x12\x10\n\x08trace_id\x18\x05 \x01(\x0c:\x02\x18\x01*\x8c\x01\n\x16\x41ggregationTemporality\x12\'\n#AGGREGATION_TEMPORALITY_UNSPECIFIED\x10\x00\x12!\n\x1d\x41GGREGATION_TEMPORALITY_DELTA\x10\x01\x12&\n\"AGGREGATION_TEMPORALITY_CUMULATIVE\x10\x02\x42t\n!io.opentelemetry.proto.metrics.v1B\x0cMetricsProtoP\x01Z?github.com/open-telemetry/opentelemetry-proto/gen/go/metrics/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.metrics.v1.metrics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!io.opentelemetry.proto.metrics.v1B\014MetricsProtoP\001Z?github.com/open-telemetry/opentelemetry-proto/gen/go/metrics/v1'
  _globals['_METRIC'].fields_by_name['int_gauge']._loaded_options = None
  _globals['_METRIC'].fields_by_name['int_gauge']._serialized_options = b'\030\001'
  _globals['_METRIC'].fields_by_name['int_sum']._loaded_options = None
  _globals['_METRIC'].fields_by_name['int_sum']._serialized_options = b'\030\001'
  _globals['_METRIC'].fields_by_name['int_histogram']._loaded_options = None
  _globals['_METRIC'].fields_by_name['int_histogram']._serialized_options = b'\030\001'
  _globals['_NUMBERDATAPOINT'].fields_by_name['labels']._loaded_options = None
  _globals['_NUMBERDATAPOINT'].fields_by_name['labels']._serialized_options = b'\030\001'
  _globals['_HISTOGRAMDATAPOINT'].fields_by_name['labels']._loaded_options = None
  _globals['_HISTOGRAMDATAPOINT'].fields_by_name['labels']._serialized_options = b'\030\001'
  _globals['_SUMMARYDATAPOINT'].fields_by_name['labels']._loaded_options = None
  _globals['_SUMMARYDATAPOINT'].fields_by_name['labels']._serialized_options = b'\030\001'
  _globals['_EXEMPLAR'].fields_by_name['filtered_labels']._loaded_options = None
  _globals['_EXEMPLAR'].fields_by_name['filtered_labels']._serialized_options = b'\030\001'
  _globals['_INTDATAPOINT']._loaded_options = None
  _globals['_INTDATAPOINT']._serialized_options = b'\030\001'
  _globals['_INTGAUGE']._loaded_options = None
  _globals['_INTGAUGE']._serialized_options = b'\030\001'
  _globals['_INTSUM']._loaded_options = None
  _globals['_INTSUM']._serialized_options = b'\030\001'
  _globals['_INTHISTOGRAMDATAPOINT']._loaded_options = None
  _globals['_INTHISTOGRAMDATAPOINT']._serialized_options = b'\030\001'
  _globals['_INTHISTOGRAM']._loaded_options = None
  _globals['_INTHISTOGRAM']._serialized_options = b'\030\001'
  _globals['_INTEXEMPLAR']._loaded_options = None
  _globals['_INTEXEMPLAR']._serialized_options = b'\030\001'
  _globals['_AGGREGATIONTEMPORALITY']._serialized_start=4033
  _globals['_AGGREGATIONTEMPORALITY']._serialized_end=4173
  _globals['_RESOURCEMETRICS']._serialized_start=173
  _globals['_RESOURCEMETRICS']._serialized_end=375
  _globals['_INSTRUMENTATIONLIBRARYMETRICS']._serialized_start=378
  _globals['_INSTRUMENTATIONLIBRARYMETRICS']._serialized_end=574
  _globals['_METRIC']._serialized_start=577
  _globals['_METRIC']._serialized_end=1079
  _globals['_GAUGE']._serialized_start=1081
  _globals['_GAUGE']._serialized_end=1158
  _globals['_SUM']._serialized_start=1161
  _globals['_SUM']._serialized_end=1347
  _globals['_HISTOGRAM']._serialized_start=1350
  _globals['_HISTOGRAM']._serialized_end=1523
  _globals['_SUMMARY']._serialized_start=1525
  _globals['_SUMMARY']._serialized_end=1605
  _globals['_NUMBERDATAPOINT']._serialized_start=1608
  _globals['_NUMBERDATAPOINT']._serialized_end=1916
  _globals['_HISTOGRAMDATAPOINT']._serialized_start=1919
  _globals['_HISTOGRAMDATAPOINT']._serialized_end=2258
  _globals['_SUMMARYDATAPOINT']._serialized_start=2261
  _globals['_SUMMARYDATAPOINT']._serialized_end=2632
  _globals['_SUMMARYDATAPOINT_VALUEATQUANTILE']._serialized_start=2582
  _globals['_SUMMARYDATAPOINT_VALUEATQUANTILE']._serialized_end=2632
  _globals['_EXEMPLAR']._serialized_start=2635
  _globals['_EXEMPLAR']._serialized_end=2898
  _globals['_INTDATAPOINT']._serialized_start=2901
  _globals['_INTDATAPOINT']._serialized_end=3115
  _globals['_INTGAUGE']._serialized_start=3117
  _globals['_INTGAUGE']._serialized_end=3198
  _globals['_INTSUM']._serialized_start=3201
  _globals['_INTSUM']._serialized_end=3391
  _globals['_INTHISTOGRAMDATAPOINT']._serialized_start=3394
  _globals['_INTHISTOGRAMDATAPOINT']._serialized_end=3678
  _globals['_INTHISTOGRAM']._serialized_start=3681
  _globals['_INTHISTOGRAM']._serialized_end=3864
  _globals['_INTEXEMPLAR']._serialized_start=3867
  _globals['_INTEXEMPLAR']._serialized_end=4030
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/http/json_to_metadata/v3/json_to_metadata.proto\x12\x31\x65nvoy.extensions.filters.http.json_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xee\t\n\x0eJsonToMetadata\x12\x63\n\rrequest_rules\x18\x01 \x01(\x0b\x32L.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.MatchRules\x12\x64\n\x0eresponse_rules\x18\x02 \x01(\x0b\x32L.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.MatchRules\x1a\x86\x02\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueH\x00\x12\x63\n\x04type\x18\x04 \x01(\x0e\x32K.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12(\n preserve_existing_metadata_value\x18\x05 \x01(\x08\x42\x0c\n\nvalue_type\x1a.\n\x08Selector\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\n\n\x08selector\x1a\x99\x03\n\x04Rule\x12g\n\tselectors\x18\x01 \x03(\x0b\x32J.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.SelectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x62\n\non_present\x18\x02 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x12\x62\n\non_missing\x18\x03 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x12`\n\x08on_error\x18\x04 \x01(\x0b\x32N.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.KeyValuePair\x1a\x82\x02\n\nMatchRules\x12_\n\x05rules\x18\x01 \x03(\x0b\x32\x46.envoy.extensions.filters.http.json_to_metadata.v3.JsonToMetadata.RuleB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12)\n\x13\x61llow_content_types\x18\x02 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x12 \n\x18\x61llow_empty_content_type\x18\x03 \x01(\x08\x12\x46\n\x19\x61llow_content_types_regex\x18\x04 \x01(\x0b\x32#.envoy.type.matcher.v3.RegexMatcher\"7\n\tValueType\x12\x12\n\x0ePROTOBUF_VALUE\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x42\xcd\x01\n?io.envoyproxy.envoy.extensions.filters.http.json_to_metadata.v3B\x13JsonToMetadataProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/json_to_metadata/v3;json_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.json_to_metadata.v3.json_to_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.http.json_to_metadata.v3B\023JsonToMetadataProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/json_to_metadata/v3;json_to_metadatav3\272\200\310\321\006\002\020\002'
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['key']._loaded_options = None
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['type']._loaded_options = None
  _globals['_JSONTOMETADATA_KEYVALUEPAIR'].fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_JSONTOMETADATA_SELECTOR'].fields_by_name['key']._loaded_options = None
  _globals['_JSONTOMETADATA_SELECTOR'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JSONTOMETADATA_RULE'].fields_by_name['selectors']._loaded_options = None
  _globals['_JSONTOMETADATA_RULE'].fields_by_name['selectors']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['rules']._loaded_options = None
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['allow_content_types']._loaded_options = None
  _globals['_JSONTOMETADATA_MATCHRULES'].fields_by_name['allow_content_types']._serialized_options = b'\372B\t\222\001\006\"\004r\002\020\001'
  _globals['_JSONTOMETADATA']._serialized_start=249
  _globals['_JSONTOMETADATA']._serialized_end=1511
  _globals['_JSONTOMETADATA_KEYVALUEPAIR']._serialized_start=471
  _globals['_JSONTOMETADATA_KEYVALUEPAIR']._serialized_end=733
  _globals['_JSONTOMETADATA_SELECTOR']._serialized_start=735
  _globals['_JSONTOMETADATA_SELECTOR']._serialized_end=781
  _globals['_JSONTOMETADATA_RULE']._serialized_start=784
  _globals['_JSONTOMETADATA_RULE']._serialized_end=1193
  _globals['_JSONTOMETADATA_MATCHRULES']._serialized_start=1196
  _globals['_JSONTOMETADATA_MATCHRULES']._serialized_end=1454
  _globals['_JSONTOMETADATA_VALUETYPE']._serialized_start=1456
  _globals['_JSONTOMETADATA_VALUETYPE']._serialized_end=1511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/common/fault/v3/fault.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/common/fault/v3/fault.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/common/fault/v3/fault.proto\x12(envoy.extensions.filters.common.fault.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x03\n\nFaultDelay\x12:\n\x0b\x66ixed_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12X\n\x0cheader_delay\x18\x05 \x01(\x0b\x32@.envoy.extensions.filters.common.fault.v3.FaultDelay.HeaderDelayH\x00\x12\x34\n\npercentage\x18\x04 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aI\n\x0bHeaderDelay::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.fault.v2.FaultDelay.HeaderDelay\"\x1b\n\x0e\x46\x61ultDelayType\x12\t\n\x05\x46IXED\x10\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.filter.fault.v2.FaultDelayB\x1b\n\x14\x66\x61ult_delay_secifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x01\x10\x02R\x04type\"\x80\x04\n\x0e\x46\x61ultRateLimit\x12Z\n\x0b\x66ixed_limit\x18\x01 \x01(\x0b\x32\x43.envoy.extensions.filters.common.fault.v3.FaultRateLimit.FixedLimitH\x00\x12\\\n\x0cheader_limit\x18\x03 \x01(\x0b\x32\x44.envoy.extensions.filters.common.fault.v3.FaultRateLimit.HeaderLimitH\x00\x12\x34\n\npercentage\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1ah\n\nFixedLimit\x12\x1b\n\nlimit_kbps\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit\x1aM\n\x0bHeaderLimit:>\x9a\xc5\x88\x1e\x39\n7envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.fault.v2.FaultRateLimitB\x11\n\nlimit_type\x12\x03\xf8\x42\x01\x42\xa7\x01\n6io.envoyproxy.envoy.extensions.filters.common.fault.v3B\nFaultProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/fault/v3;faultv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.common.fault.v3.fault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6io.envoyproxy.envoy.extensions.filters.common.fault.v3B\nFaultProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/fault/v3;faultv3\272\200\310\321\006\002\020\002'
  _globals['_FAULTDELAY_HEADERDELAY']._loaded_options = None
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.fault.v2.FaultDelay.HeaderDelay'
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._loaded_options = None
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._serialized_options = b'\370B\001'
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._loaded_options = None
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_FAULTDELAY']._loaded_options = None
  _globals['_FAULTDELAY']._serialized_options = b'\232\305\210\036)\n\'envoy.config.filter.fault.v2.FaultDelay'
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._loaded_options = None
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._serialized_options = b'\372B\0042\002(\001'
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.fault.v2.FaultRateLimit.FixedLimit'
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_options = b'\232\305\210\0369\n7envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimit'
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._loaded_options = None
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._serialized_options = b'\370B\001'
  _globals['_FAULTRATELIMIT']._loaded_options = None
  _globals['_FAULTRATELIMIT']._serialized_options = b'\232\305\210\036-\n+envoy.config.filter.fault.v2.FaultRateLimit'
  _globals['_FAULTDELAY']._serialized_start=251
  _globals['_FAULTDELAY']._serialized_end=666
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_start=469
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_end=542
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_start=544
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_end=571
  _globals['_FAULTRATELIMIT']._serialized_start=669
  _globals['_FAULTRATELIMIT']._serialized_end=1181
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_start=927
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_end=1031
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_start=1033
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_end=1110
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/http/original_ip_detection/custom_header/v3/custom_header.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/http/original_ip_detection/custom_header/v3/custom_header.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPenvoy/extensions/http/original_ip_detection/custom_header/v3/custom_header.proto\x12<envoy.extensions.http.original_ip_detection.custom_header.v3\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa2\x01\n\x12\x43ustomHeaderConfig\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x01\x12\x31\n)allow_extension_to_set_address_as_trusted\x18\x02 \x01(\x08\x12\x35\n\x12reject_with_status\x18\x03 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatusB\xde\x01\nJio.envoyproxy.envoy.extensions.http.original_ip_detection.custom_header.v3B\x11\x43ustomHeaderProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/original_ip_detection/custom_header/v3;custom_headerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.original_ip_detection.custom_header.v3.custom_header_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nJio.envoyproxy.envoy.extensions.http.original_ip_detection.custom_header.v3B\021CustomHeaderProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/original_ip_detection/custom_header/v3;custom_headerv3\272\200\310\321\006\002\020\002'
  _globals['_CUSTOMHEADERCONFIG'].fields_by_name['header_name']._loaded_options = None
  _globals['_CUSTOMHEADERCONFIG'].fields_by_name['header_name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\001'
  _globals['_CUSTOMHEADERCONFIG']._serialized_start=236
  _globals['_CUSTOMHEADERCONFIG']._serialized_end=398
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/clusters/common/dns/v3/dns.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/clusters/common/dns/v3/dns.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1envoy/extensions/clusters/common/dns/v3/dns.proto\x12\'envoy.extensions.clusters.common.dns.v3\x1a\x1dudpa/annotations/status.proto*a\n\x0f\x44nsLookupFamily\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x0b\n\x07V4_ONLY\x10\x02\x12\x0b\n\x07V6_ONLY\x10\x03\x12\x10\n\x0cV4_PREFERRED\x10\x04\x12\x07\n\x03\x41LL\x10\x05\x42\xa1\x01\n5io.envoyproxy.envoy.extensions.clusters.common.dns.v3B\x08\x44nsProtoP\x01ZTgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/common/dns/v3;dnsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.clusters.common.dns.v3.dns_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5io.envoyproxy.envoy.extensions.clusters.common.dns.v3B\010DnsProtoP\001ZTgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/common/dns/v3;dnsv3\272\200\310\321\006\002\020\002'
  _globals['_DNSLOOKUPFAMILY']._serialized_start=125
  _globals['_DNSLOOKUPFAMILY']._serialized_end=222
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/listener/v3/listener_components.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/listener/v3/listener_components.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/config/listener/v3/listener_components.proto\x12\x18\x65nvoy.config.listener.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12G\n\x10\x63onfig_discovery\x18\x05 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSourceH\x00:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.api.v2.listener.FilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04J\x04\x08\x02\x10\x03R\x06\x63onfig\"\xb4\x05\n\x10\x46ilterChainMatch\x12\x43\n\x10\x64\x65stination_port\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03(\x01\x12\x36\n\rprefix_ranges\x18\x03 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12\x16\n\x0e\x61\x64\x64ress_suffix\x18\x04 \x01(\t\x12\x30\n\nsuffix_len\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x44\n\x1b\x64irect_source_prefix_ranges\x18\r \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12^\n\x0bsource_type\x18\x0c \x01(\x0e\x32?.envoy.config.listener.v3.FilterChainMatch.ConnectionSourceTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12=\n\x14source_prefix_ranges\x18\x06 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12&\n\x0csource_ports\x18\x07 \x03(\rB\x10\xfa\x42\r\x92\x01\n\"\x08*\x06\x18\xff\xff\x03(\x01\x12\x14\n\x0cserver_names\x18\x0b \x03(\t\x12\x1a\n\x12transport_protocol\x18\t \x01(\t\x12\x1d\n\x15\x61pplication_protocols\x18\n \x03(\t\"F\n\x14\x43onnectionSourceType\x12\x07\n\x03\x41NY\x10\x00\x12\x17\n\x13SAME_IP_OR_LOOPBACK\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.listener.FilterChainMatchJ\x04\x08\x01\x10\x02\"\xec\x03\n\x0b\x46ilterChain\x12\x46\n\x12\x66ilter_chain_match\x18\x01 \x01(\x0b\x32*.envoy.config.listener.v3.FilterChainMatch\x12\x31\n\x07\x66ilters\x18\x03 \x03(\x0b\x32 .envoy.config.listener.v3.Filter\x12@\n\x0fuse_proxy_proto\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x30\n\x08metadata\x18\x05 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12?\n\x10transport_socket\x18\x06 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocket\x12\x43\n transport_socket_connect_timeout\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04name\x18\x07 \x01(\t:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.listener.FilterChainJ\x04\x08\x02\x10\x03J\x04\x08\x08\x10\tR\x0btls_contextR\x17on_demand_configuration\"\xfe\x04\n!ListenerFilterChainMatchPredicate\x12X\n\x08or_match\x18\x01 \x01(\x0b\x32\x44.envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12Y\n\tand_match\x18\x02 \x01(\x0b\x32\x44.envoy.config.listener.v3.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12P\n\tnot_match\x18\x03 \x01(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12;\n\x16\x64\x65stination_port_range\x18\x05 \x01(\x0b\x32\x19.envoy.type.v3.Int32RangeH\x00\x1a\xa9\x01\n\x08MatchSet\x12T\n\x05rules\x18\x01 \x03(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:G\x9a\xc5\x88\x1e\x42\n@envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSet:>\x9a\xc5\x88\x1e\x39\n7envoy.api.v2.listener.ListenerFilterChainMatchPredicateB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\xbe\x02\n\x0eListenerFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12G\n\x10\x63onfig_discovery\x18\x05 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSourceH\x00\x12T\n\x0f\x66ilter_disabled\x18\x04 \x01(\x0b\x32;.envoy.config.listener.v3.ListenerFilterChainMatchPredicate:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.listener.ListenerFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigB\x97\x01\n&io.envoyproxy.envoy.config.listener.v3B\x17ListenerComponentsProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.listener.v3.listener_components_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&io.envoyproxy.envoy.config.listener.v3B\027ListenerComponentsProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\272\200\310\321\006\002\020\002'
  _globals['_FILTER'].fields_by_name['name']._loaded_options = None
  _globals['_FILTER'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILTER']._loaded_options = None
  _globals['_FILTER']._serialized_options = b'\232\305\210\036\036\n\034envoy.api.v2.listener.Filter'
  _globals['_FILTERCHAINMATCH'].fields_by_name['destination_port']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['destination_port']._serialized_options = b'\372B\010*\006\030\377\377\003(\001'
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_type']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_ports']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_ports']._serialized_options = b'\372B\r\222\001\n\"\010*\006\030\377\377\003(\001'
  _globals['_FILTERCHAINMATCH']._loaded_options = None
  _globals['_FILTERCHAINMATCH']._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.listener.FilterChainMatch'
  _globals['_FILTERCHAIN'].fields_by_name['use_proxy_proto']._loaded_options = None
  _globals['_FILTERCHAIN'].fields_by_name['use_proxy_proto']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_FILTERCHAIN']._loaded_options = None
  _globals['_FILTERCHAIN']._serialized_options = b'\232\305\210\036#\n!envoy.api.v2.listener.FilterChain'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET'].fields_by_name['rules']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._serialized_options = b'\232\305\210\036B\n@envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSet'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].oneofs_by_name['rule']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].fields_by_name['any_match']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].fields_by_name['any_match']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._serialized_options = b'\232\305\210\0369\n7envoy.api.v2.listener.ListenerFilterChainMatchPredicate'
  _globals['_LISTENERFILTER'].fields_by_name['name']._loaded_options = None
  _globals['_LISTENERFILTER'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LISTENERFILTER']._loaded_options = None
  _globals['_LISTENERFILTER']._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.listener.ListenerFilter'
  _globals['_FILTER']._serialized_start=438
  _globals['_FILTER']._serialized_end=660
  _globals['_FILTERCHAINMATCH']._serialized_start=663
  _globals['_FILTERCHAINMATCH']._serialized_end=1355
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE']._serialized_start=1232
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE']._serialized_end=1302
  _globals['_FILTERCHAIN']._serialized_start=1358
  _globals['_FILTERCHAIN']._serialized_end=1850
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._serialized_start=1853
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._serialized_end=2491
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._serialized_start=2245
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._serialized_end=2414
  _globals['_LISTENERFILTER']._serialized_start=2494
  _globals['_LISTENERFILTER']._serialized_end=2812
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/stateful_session/v3/stateful_session.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/stateful_session/v3/stateful_session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/http/stateful_session/v3/stateful_session.proto\x12\x31\x65nvoy.extensions.filters.http.stateful_session.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"d\n\x0fStatefulSession\x12\x41\n\rsession_state\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x0e\n\x06strict\x18\x02 \x01(\x08\"\xa7\x01\n\x17StatefulSessionPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12^\n\x10stateful_session\x18\x02 \x01(\x0b\x32\x42.envoy.extensions.filters.http.stateful_session.v3.StatefulSessionH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\x42\xce\x01\n?io.envoyproxy.envoy.extensions.filters.http.stateful_session.v3B\x14StatefulSessionProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/stateful_session/v3;stateful_sessionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.stateful_session.v3.stateful_session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.http.stateful_session.v3B\024StatefulSessionProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/stateful_session/v3;stateful_sessionv3\272\200\310\321\006\002\020\002'
  _globals['_STATEFULSESSIONPERROUTE'].oneofs_by_name['override']._loaded_options = None
  _globals['_STATEFULSESSIONPERROUTE'].oneofs_by_name['override']._serialized_options = b'\370B\001'
  _globals['_STATEFULSESSIONPERROUTE'].fields_by_name['disabled']._loaded_options = None
  _globals['_STATEFULSESSIONPERROUTE'].fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_STATEFULSESSION']._serialized_start=221
  _globals['_STATEFULSESSION']._serialized_end=321
  _globals['_STATEFULSESSIONPERROUTE']._serialized_start=324
  _globals['_STATEFULSESSIONPERROUTE']._serialized_end=491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/fault/v2/fault.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/fault/v2/fault.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/config/filter/fault/v2/fault.proto\x12\x1c\x65nvoy.config.filter.fault.v2\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe9\x02\n\nFaultDelay\x12O\n\x04type\x18\x01 \x01(\x0e\x32\x37.envoy.config.filter.fault.v2.FaultDelay.FaultDelayTypeB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12:\n\x0b\x66ixed_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12L\n\x0cheader_delay\x18\x05 \x01(\x0b\x32\x34.envoy.config.filter.fault.v2.FaultDelay.HeaderDelayH\x00\x12\x31\n\npercentage\x18\x04 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x1a\r\n\x0bHeaderDelay\"\x1b\n\x0e\x46\x61ultDelayType\x12\t\n\x05\x46IXED\x10\x00\x42\x1b\n\x14\x66\x61ult_delay_secifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03\"\xb2\x02\n\x0e\x46\x61ultRateLimit\x12N\n\x0b\x66ixed_limit\x18\x01 \x01(\x0b\x32\x37.envoy.config.filter.fault.v2.FaultRateLimit.FixedLimitH\x00\x12P\n\x0cheader_limit\x18\x03 \x01(\x0b\x32\x38.envoy.config.filter.fault.v2.FaultRateLimit.HeaderLimitH\x00\x12\x31\n\npercentage\x18\x02 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x1a)\n\nFixedLimit\x12\x1b\n\nlimit_kbps\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x1a\r\n\x0bHeaderLimitB\x11\n\nlimit_type\x12\x03\xf8\x42\x01\x42\xbf\x01\n*io.envoyproxy.envoy.config.filter.fault.v2B\nFaultProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/config/filter/fault/v2;faultv2\xf2\x98\xfe\x8f\x05*\x12(envoy.extensions.filters.common.fault.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.fault.v2.fault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*io.envoyproxy.envoy.config.filter.fault.v2B\nFaultProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/config/filter/fault/v2;faultv2\362\230\376\217\005*\022(envoy.extensions.filters.common.fault.v3\272\200\310\321\006\002\020\001'
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._loaded_options = None
  _globals['_FAULTDELAY'].oneofs_by_name['fault_delay_secifier']._serialized_options = b'\370B\001'
  _globals['_FAULTDELAY'].fields_by_name['type']._loaded_options = None
  _globals['_FAULTDELAY'].fields_by_name['type']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._loaded_options = None
  _globals['_FAULTDELAY'].fields_by_name['fixed_delay']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._loaded_options = None
  _globals['_FAULTRATELIMIT_FIXEDLIMIT'].fields_by_name['limit_kbps']._serialized_options = b'\372B\0042\002(\001'
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._loaded_options = None
  _globals['_FAULTRATELIMIT'].oneofs_by_name['limit_type']._serialized_options = b'\370B\001'
  _globals['_FAULTDELAY']._serialized_start=258
  _globals['_FAULTDELAY']._serialized_end=619
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_start=542
  _globals['_FAULTDELAY_HEADERDELAY']._serialized_end=555
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_start=557
  _globals['_FAULTDELAY_FAULTDELAYTYPE']._serialized_end=584
  _globals['_FAULTRATELIMIT']._serialized_start=622
  _globals['_FAULTRATELIMIT']._serialized_end=928
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_start=853
  _globals['_FAULTRATELIMIT_FIXEDLIMIT']._serialized_end=894
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_start=896
  _globals['_FAULTRATELIMIT_HEADERLIMIT']._serialized_end=909
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/http/aws_lambda/v3/aws_lambda.proto\x12+envoy.extensions.filters.http.aws_lambda.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x06\x43onfig\x12\x14\n\x03\x61rn\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\x13payload_passthrough\x18\x02 \x01(\x08\x12\x65\n\x0finvocation_mode\x18\x03 \x01(\x0e\x32\x42.envoy.extensions.filters.http.aws_lambda.v3.Config.InvocationModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x14\n\x0chost_rewrite\x18\x04 \x01(\t\x12\x1b\n\x13\x63redentials_profile\x18\x05 \x01(\t\x12M\n\x0b\x63redentials\x18\x06 \x01(\x0b\x32\x38.envoy.extensions.filters.http.aws_lambda.v3.Credentials\"3\n\x0eInvocationMode\x12\x0f\n\x0bSYNCHRONOUS\x10\x00\x12\x10\n\x0c\x41SYNCHRONOUS\x10\x01:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.aws_lambda.v2alpha.Config\"h\n\x0b\x43redentials\x12\x1e\n\raccess_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\"\n\x11secret_access_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rsession_token\x18\x03 \x01(\t\"\x9f\x01\n\x0ePerRouteConfig\x12J\n\rinvoke_config\x18\x01 \x01(\x0b\x32\x33.envoy.extensions.filters.http.aws_lambda.v3.Config:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfigB\xb6\x01\n9io.envoyproxy.envoy.extensions.filters.http.aws_lambda.v3B\x0e\x41wsLambdaProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_lambda/v3;aws_lambdav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.aws_lambda.v3.aws_lambda_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9io.envoyproxy.envoy.extensions.filters.http.aws_lambda.v3B\016AwsLambdaProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_lambda/v3;aws_lambdav3\272\200\310\321\006\002\020\002'
  _globals['_CONFIG'].fields_by_name['arn']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['arn']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CONFIG'].fields_by_name['invocation_mode']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['invocation_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CONFIG']._loaded_options = None
  _globals['_CONFIG']._serialized_options = b'\232\305\210\0364\n2envoy.config.filter.http.aws_lambda.v2alpha.Config'
  _globals['_CREDENTIALS'].fields_by_name['access_key_id']._loaded_options = None
  _globals['_CREDENTIALS'].fields_by_name['access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREDENTIALS'].fields_by_name['secret_access_key']._loaded_options = None
  _globals['_CREDENTIALS'].fields_by_name['secret_access_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PERROUTECONFIG']._loaded_options = None
  _globals['_PERROUTECONFIG']._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.aws_lambda.v2alpha.PerRouteConfig'
  _globals['_CONFIG']._serialized_start=201
  _globals['_CONFIG']._serialized_end=605
  _globals['_CONFIG_INVOCATIONMODE']._serialized_start=495
  _globals['_CONFIG_INVOCATIONMODE']._serialized_end=546
  _globals['_CREDENTIALS']._serialized_start=607
  _globals['_CREDENTIALS']._serialized_end=711
  _globals['_PERROUTECONFIG']._serialized_start=714
  _globals['_PERROUTECONFIG']._serialized_end=873
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/http/rate_limit/v2/rate_limit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/http/rate_limit/v2/rate_limit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.ratelimit.v2 import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v2_dot_rls__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/config/filter/http/rate_limit/v2/rate_limit.proto\x12&envoy.config.filter.http.rate_limit.v2\x1a#envoy/config/ratelimit/v2/rls.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc1\x02\n\tRateLimit\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x05stage\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x37\n\x0crequest_type\x18\x03 \x01(\tB!\xfa\x42\x1er\x1cR\x08internalR\x08\x65xternalR\x04\x62othR\x00\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x05 \x01(\x08\x12*\n\"rate_limited_as_resource_exhausted\x18\x06 \x01(\x08\x12W\n\x12rate_limit_service\x18\x07 \x01(\x0b\x32\x31.envoy.config.ratelimit.v2.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xde\x01\n4io.envoyproxy.envoy.config.filter.http.rate_limit.v2B\x0eRateLimitProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/rate_limit/v2;rate_limitv2\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.rate_limit.v2.rate_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4io.envoyproxy.envoy.config.filter.http.rate_limit.v2B\016RateLimitProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/rate_limit/v2;rate_limitv2\362\230\376\217\005,\022*envoy.extensions.filters.http.ratelimit.v3\272\200\310\321\006\002\020\001'
  _globals['_RATELIMIT'].fields_by_name['domain']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['domain']._serialized_options = b'\372B\004r\002 \001'
  _globals['_RATELIMIT'].fields_by_name['stage']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _globals['_RATELIMIT'].fields_by_name['request_type']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['request_type']._serialized_options = b'\372B\036r\034R\010internalR\010externalR\004bothR\000'
  _globals['_RATELIMIT'].fields_by_name['rate_limit_service']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['rate_limit_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_RATELIMIT']._serialized_start=257
  _globals['_RATELIMIT']._serialized_end=578
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/listener/udp_listener_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/listener/udp_listener_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/api/v2/listener/udp_listener_config.proto\x12\x15\x65nvoy.api.v2.listener\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x9a\x01\n\x11UdpListenerConfig\x12\x19\n\x11udp_listener_name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\x1c\n\x1a\x41\x63tiveRawUdpListenerConfigB\xdc\x01\n#io.envoyproxy.envoy.api.v2.listenerB\x16UdpListenerConfigProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x1a\x45nvoy::Api::V2::ListenerNS\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener.udp_listener_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.listenerB\026UdpListenerConfigProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\252\002\027Envoy.Api.V2.ListenerNS\352\002\032Envoy::Api::V2::ListenerNS\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001'
  _globals['_UDPLISTENERCONFIG'].fields_by_name['config']._loaded_options = None
  _globals['_UDPLISTENERCONFIG'].fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_UDPLISTENERCONFIG']._serialized_start=195
  _globals['_UDPLISTENERCONFIG']._serialized_end=349
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._serialized_start=351
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._serialized_end=379
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: opencensus/proto/trace/v1/trace_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'opencensus/proto/trace/v1/trace_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,opencensus/proto/trace/v1/trace_config.proto\x12\x19opencensus.proto.trace.v1\"\x87\x03\n\x0bTraceConfig\x12L\n\x13probability_sampler\x18\x01 \x01(\x0b\x32-.opencensus.proto.trace.v1.ProbabilitySamplerH\x00\x12\x46\n\x10\x63onstant_sampler\x18\x02 \x01(\x0b\x32*.opencensus.proto.trace.v1.ConstantSamplerH\x00\x12O\n\x15rate_limiting_sampler\x18\x03 \x01(\x0b\x32..opencensus.proto.trace.v1.RateLimitingSamplerH\x00\x12 \n\x18max_number_of_attributes\x18\x04 \x01(\x03\x12!\n\x19max_number_of_annotations\x18\x05 \x01(\x03\x12$\n\x1cmax_number_of_message_events\x18\x06 \x01(\x03\x12\x1b\n\x13max_number_of_links\x18\x07 \x01(\x03\x42\t\n\x07sampler\"1\n\x12ProbabilitySampler\x12\x1b\n\x13samplingProbability\x18\x01 \x01(\x01\"\xa6\x01\n\x0f\x43onstantSampler\x12M\n\x08\x64\x65\x63ision\x18\x01 \x01(\x0e\x32;.opencensus.proto.trace.v1.ConstantSampler.ConstantDecision\"D\n\x10\x43onstantDecision\x12\x0e\n\nALWAYS_OFF\x10\x00\x12\r\n\tALWAYS_ON\x10\x01\x12\x11\n\rALWAYS_PARENT\x10\x02\"\"\n\x13RateLimitingSampler\x12\x0b\n\x03qps\x18\x01 \x01(\x03\x42\x92\x01\n\x1cio.opencensus.proto.trace.v1B\x10TraceConfigProtoP\x01ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/trace/v1\xea\x02\x19OpenCensus.Proto.Trace.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.trace.v1.trace_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.opencensus.proto.trace.v1B\020TraceConfigProtoP\001ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/trace/v1\352\002\031OpenCensus.Proto.Trace.V1'
  _globals['_TRACECONFIG']._serialized_start=76
  _globals['_TRACECONFIG']._serialized_end=467
  _globals['_PROBABILITYSAMPLER']._serialized_start=469
  _globals['_PROBABILITYSAMPLER']._serialized_end=518
  _globals['_CONSTANTSAMPLER']._serialized_start=521
  _globals['_CONSTANTSAMPLER']._serialized_end=687
  _globals['_CONSTANTSAMPLER_CONSTANTDECISION']._serialized_start=619
  _globals['_CONSTANTSAMPLER_CONSTANTDECISION']._serialized_end=687
  _globals['_RATELIMITINGSAMPLER']._serialized_start=689
  _globals['_RATELIMITINGSAMPLER']._serialized_end=723
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v3/certs.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v3/certs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65nvoy/admin/v3/certs.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"j\n\x0c\x43\x65rtificates\x12\x31\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x1b.envoy.admin.v3.Certificate:\'\x9a\xc5\x88\x1e\"\n envoy.admin.v2alpha.Certificates\"\xa2\x01\n\x0b\x43\x65rtificate\x12\x33\n\x07\x63\x61_cert\x18\x01 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails\x12\x36\n\ncert_chain\x18\x02 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.admin.v2alpha.Certificate\"\xe2\x03\n\x12\x43\x65rtificateDetails\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12?\n\x11subject_alt_names\x18\x03 \x03(\x0b\x32$.envoy.admin.v3.SubjectAlternateName\x12\x1d\n\x15\x64\x61ys_until_expiration\x18\x04 \x01(\x04\x12.\n\nvalid_from\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x0cocsp_details\x18\x07 \x01(\x0b\x32..envoy.admin.v3.CertificateDetails.OcspDetails\x1am\n\x0bOcspDetails\x12.\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:-\x9a\xc5\x88\x1e(\n&envoy.admin.v2alpha.CertificateDetails\"\x83\x01\n\x14SubjectAlternateName\x12\r\n\x03\x64ns\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x14\n\nip_address\x18\x03 \x01(\tH\x00:/\x9a\xc5\x88\x1e*\n(envoy.admin.v2alpha.SubjectAlternateNameB\x06\n\x04nameBs\n\x1cio.envoyproxy.envoy.admin.v3B\nCertsProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.certs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\nCertsProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_CERTIFICATES']._loaded_options = None
  _globals['_CERTIFICATES']._serialized_options = b'\232\305\210\036\"\n envoy.admin.v2alpha.Certificates'
  _globals['_CERTIFICATE']._loaded_options = None
  _globals['_CERTIFICATE']._serialized_options = b'\232\305\210\036!\n\037envoy.admin.v2alpha.Certificate'
  _globals['_CERTIFICATEDETAILS']._loaded_options = None
  _globals['_CERTIFICATEDETAILS']._serialized_options = b'\232\305\210\036(\n&envoy.admin.v2alpha.CertificateDetails'
  _globals['_SUBJECTALTERNATENAME']._loaded_options = None
  _globals['_SUBJECTALTERNATENAME']._serialized_options = b'\232\305\210\036*\n(envoy.admin.v2alpha.SubjectAlternateName'
  _globals['_CERTIFICATES']._serialized_start=145
  _globals['_CERTIFICATES']._serialized_end=251
  _globals['_CERTIFICATE']._serialized_start=254
  _globals['_CERTIFICATE']._serialized_end=416
  _globals['_CERTIFICATEDETAILS']._serialized_start=419
  _globals['_CERTIFICATEDETAILS']._serialized_end=901
  _globals['_CERTIFICATEDETAILS_OCSPDETAILS']._serialized_start=745
  _globals['_CERTIFICATEDETAILS_OCSPDETAILS']._serialized_end=854
  _globals['_SUBJECTALTERNATENAME']._serialized_start=904
  _globals['_SUBJECTALTERNATENAME']._serialized_end=1035
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from envoy.service.status.v2 import csds_pb2 as envoy_dot_service_dot_status_dot_v2_dot_csds__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in envoy/service/status/v2/csds_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ClientStatusDiscoveryServiceStub(object):
    """[#protodoc-title: Client Status Discovery Service (CSDS)]

    CSDS is Client Status Discovery Service. It can be used to get the status of
    an xDS-compliant client from the management server's point of view. In the
    future, it can potentially be used as an interface to get the current
    state directly from the client.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamClientStatus = channel.stream_stream(
                '/envoy.service.status.v2.ClientStatusDiscoveryService/StreamClientStatus',
                request_serializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.FromString,
                _registered_method=True)
        self.FetchClientStatus = channel.unary_unary(
                '/envoy.service.status.v2.ClientStatusDiscoveryService/FetchClientStatus',
                request_serializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.FromString,
                _registered_method=True)


class ClientStatusDiscoveryServiceServicer(object):
    """[#protodoc-title: Client Status Discovery Service (CSDS)]

    CSDS is Client Status Discovery Service. It can be used to get the status of
    an xDS-compliant client from the management server's point of view. In the
    future, it can potentially be used as an interface to get the current
    state directly from the client.
    """

    def StreamClientStatus(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchClientStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientStatusDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamClientStatus': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamClientStatus,
                    request_deserializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.FromString,
                    response_serializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.SerializeToString,
            ),
            'FetchClientStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchClientStatus,
                    request_deserializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.FromString,
                    response_serializer=envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.status.v2.ClientStatusDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('envoy.service.status.v2.ClientStatusDiscoveryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ClientStatusDiscoveryService(object):
    """[#protodoc-title: Client Status Discovery Service (CSDS)]

    CSDS is Client Status Discovery Service. It can be used to get the status of
    an xDS-compliant client from the management server's point of view. In the
    future, it can potentially be used as an interface to get the current
    state directly from the client.
    """

    @staticmethod
    def StreamClientStatus(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/envoy.service.status.v2.ClientStatusDiscoveryService/StreamClientStatus',
            envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.SerializeToString,
            envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FetchClientStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/envoy.service.status.v2.ClientStatusDiscoveryService/FetchClientStatus',
            envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusRequest.SerializeToString,
            envoy_dot_service_dot_status_dot_v2_dot_csds__pb2.ClientStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/bandwidth_limit/v3/bandwidth_limit.proto\x12\x30\x65nvoy.extensions.filters.http.bandwidth_limit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfe\x03\n\x0e\x42\x61ndwidthLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12j\n\x0b\x65nable_mode\x18\x02 \x01(\x0e\x32K.envoy.extensions.filters.http.bandwidth_limit.v3.BandwidthLimit.EnableModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x39\n\nlimit_kbps\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02(\x01\x12\x43\n\rfill_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\"\x02\x08\x01\x32\x05\x10\x80\xda\xc4\t\x12\x41\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12 \n\x18\x65nable_response_trailers\x18\x06 \x01(\x08\x12,\n\x17response_trailer_prefix\x18\x07 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"O\n\nEnableMode\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\x0c\n\x08RESPONSE\x10\x02\x12\x18\n\x14REQUEST_AND_RESPONSE\x10\x03\x42\xca\x01\n>io.envoyproxy.envoy.extensions.filters.http.bandwidth_limit.v3B\x13\x42\x61ndwidthLimitProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/bandwidth_limit/v3;bandwidth_limitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.bandwidth_limit.v3.bandwidth_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.bandwidth_limit.v3B\023BandwidthLimitProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/bandwidth_limit/v3;bandwidth_limitv3\272\200\310\321\006\002\020\002'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['enable_mode']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['enable_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['limit_kbps']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['limit_kbps']._serialized_options = b'\372B\0042\002(\001'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['fill_interval']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['fill_interval']._serialized_options = b'\372B\016\252\001\013\"\002\010\0012\005\020\200\332\304\t'
  _globals['_BANDWIDTHLIMIT'].fields_by_name['response_trailer_prefix']._loaded_options = None
  _globals['_BANDWIDTHLIMIT'].fields_by_name['response_trailer_prefix']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _globals['_BANDWIDTHLIMIT']._serialized_start=278
  _globals['_BANDWIDTHLIMIT']._serialized_end=788
  _globals['_BANDWIDTHLIMIT_ENABLEMODE']._serialized_start=709
  _globals['_BANDWIDTHLIMIT_ENABLEMODE']._serialized_end=788
# @@protoc_insertion_point(module_scope)
